using System;
using Server;
using Server.Gumps;
using Server.Network;
using Server.Menus;
using Server.Menus.Questions;

namespace Server.Engines.Help
{
	public class ContainedMenu : QuestionMenu
	{
		private Mobile m_From;

		public ContainedMenu( Mobile from ) : base( "You already have an open help request. We will have someone assist you as soon as possible.  What would you like to do?", new string[]{ "Leave my old help request like it is.", "Remove my help request from the queue." } )
		{
			m_From = from;
		}

		public override void OnCancel( NetState state )
		{
			m_From.SendLocalizedMessage( 1005306 ); // Help request unchanged.
		}

		public override void OnResponse( NetState state, int index )
		{
			if ( index == 0 )
			{
				m_From.SendLocalizedMessage( 1005306 ); // Help request unchanged.
			}
			else if ( index == 1 )
			{
				PageEntry entry = PageQueue.GetEntry( m_From );

				if ( entry != null && entry.Handler == null )
				{
					m_From.SendLocalizedMessage( 1005307 ); // Removed help request.
					PageQueue.Remove( entry );
				}
				else
				{
					m_From.SendLocalizedMessage( 1005306 ); // Help request unchanged.
				}
			}
		}
	}

	public class HelpGump : Gump
	{
		public static void Initialize()
		{
			EventSink.HelpRequest += new HelpRequestEventHandler( EventSink_HelpRequest );
		}

		private static void EventSink_HelpRequest( HelpRequestEventArgs e )
		{
			if ( PageQueue.Contains( e.Mobile ) )
				e.Mobile.SendMenu( new ContainedMenu( e.Mobile ) );
			else
				e.Mobile.SendGump( new HelpGump() );
		}

		public HelpGump() : base( 0, 0 )
		{
			Add( new GumpBackground( 100, 25, 440, 430, 2600 ) );

			Add( new GumpPage( 0 ) );
			Add( new GumpHtmlLocalized( 150, 50, 360, 40, 1001002, false, false ) );
			Add( new GumpButton( 425, 415, 2073, 2072, 0, GumpButtonType.Reply, 0 ) );

			Add( new GumpPage( 1 ) );
			Add( new GumpButton( 130, 90, 5540, 5541, 5, GumpButtonType.Reply, 2 ) );
			Add( new GumpHtml( 160, 90, 350, 74, "<u>General question about Ultima Online.</u> Select this option if you have a general gameplay question, need help learning to use a skill, or if you would like to search the UO Knowledge Base.", true, true ) );
			Add( new GumpButton( 130, 170, 5540, 5541, 2, GumpButtonType.Reply, 0 ) );
			Add( new GumpHtml( 160, 170, 350, 74, "<u>My character is physically stuck in the game.</u> This choice only covers cases where your character is physically stuck in a location they cannot move out of. This option will only work two times in 24 hours.", true, true ) );
			Add( new GumpButton( 130, 250, 5540, 5541, 3, GumpButtonType.Page, 3 ) );
			Add( new GumpHtml( 160, 250, 350, 74, "<u>Another player is harassing me.</u> Another player is verbally harassing your character. When you select this option you will be sending a text log to Origin Systems. To see what constitutes harassment please visit http://support.uo.com/gm_9.html.", true, true ) );
			Add( new GumpButton( 130, 330, 5540, 5541, 1, GumpButtonType.Page, 2 ) );
			Add( new GumpHtml( 160, 330, 350, 74, "<u>Other.</u> If you are experiencing a problem in the game that does not fall into one of the other categories or is not addressed on the Support web page (located at http://support.uo.com), please use this option.", true, true ) );

			Add( new GumpPage( 2 ) );
			Add( new GumpButton( 130, 90, 5540, 5541, 6, GumpButtonType.Reply, 0 ) );
			Add( new GumpHtml( 160, 90, 350, 74, "<u>Report a bug or contact Origin.</u> Use this option to launch your web browser and mail in a bug report. Your report will be read by our Quality Assurance Staff. We apologize for not being able to reply to individual reports. ", true, true ) );
			Add( new GumpButton( 130, 170, 5540, 5541, 10, GumpButtonType.Reply, 0 ) );
			Add( new GumpHtml( 160, 170, 350, 74, "<u>Suggestion for the Game.</u> If you'd like to make a suggestion for the game, it should be directed to the Development Team Members who participate in the discussion forums on the UO.Com web site. Choosing this option will take you to the Discussion Forums. ", true, true ) );
			Add( new GumpButton( 130, 250, 5540, 5541, 9, GumpButtonType.Reply, 0 ) );
			Add( new GumpHtml( 160, 250, 350, 74, "<u>Account Management</u> For questions regarding your account such as forgotten passwords, payment options, account activation, and account transfer, please choose this option.", true, true ) );
			Add( new GumpButton( 130, 330, 5540, 5541, 4, GumpButtonType.Reply, 0 ) );
			Add( new GumpHtml( 160, 330, 350, 74, "<u>Other.</u> If you are experiencing a problem in the game that does not fall into one of the other categories or is not addressed on the Support web page (located at http://support.uo.com), and requires in-game assistance, use this option. ", true, true ) );

			Add( new GumpPage( 3 ) );
			Add( new GumpHtmlLocalized( 130, 90, 380, 250, 1001013, true, true ) );
			Add( new GumpButton( 150, 350, 5540, 5541, 3, GumpButtonType.Reply, 0 ) );
			Add( new GumpHtmlLocalized( 180, 350, 335, 40, 1001014, false, false ) );
			Add( new GumpButton( 150, 385, 5540, 5541, 9, GumpButtonType.Page, 1 ) );
			Add( new GumpHtmlLocalized( 180, 385, 335, 40, 1001015, false, false ) );
		}

		public override void OnResponse( NetState state, RelayInfo info )
		{
			Mobile from = state.Mobile;

			switch ( info.ButtonID )
			{
				case 0: // Close/Cancel
				{
					from.SendLocalizedMessage( 501235 ); // Help request aborted.

					break;
				}
				case 2: // Stuck
				{
					if ( state.Mobile.Region is Server.Regions.Jail )
					{
						from.SendLocalizedMessage( 1041530 ); // You'll need a better jailbreak plan then that!
					}
					else if ( state.Mobile.CanUseStuckMenu() && state.Mobile.Region.CanUseStuckMenu( state.Mobile ) )
					{
						from.SendMenu( new StuckMenu( from, from, true ) );
					}
					else
					{
						from.SendLocalizedMessage( 501232 ); // Please enter a brief description (up to 40 characters) of your problem:
						from.Prompt = new PagePrompt( PageType.Stuck );
					}

					break;
				}
				case 4: // Other
				{
					from.SendLocalizedMessage( 501232 ); // Please enter a brief description (up to 40 characters) of your problem:
					from.Prompt = new PagePrompt( PageType.Other );

					break;
				}
				case 5: // General question
				{
					from.SendLocalizedMessage( 501232 ); // Please enter a brief description (up to 40 characters) of your problem:
					from.Prompt = new PagePrompt( PageType.Question );

					break;
				}
				case 6: // Report bug or contact Origin
				{
					from.SendLocalizedMessage( 501232 ); // Please enter a brief description (up to 40 characters) of your problem:
					from.Prompt = new PagePrompt( PageType.Bug );

					break;
				}
				case 9: // Account management
				{
					from.SendLocalizedMessage( 501232 ); // Please enter a brief description (up to 40 characters) of your problem:
					state.Mobile.Prompt = new PagePrompt( PageType.Account );

					break;
				}
				case 10: // Game suggestion
				{
					from.SendLocalizedMessage( 501232 ); // Please enter a brief description (up to 40 characters) of your problem:
					from.Prompt = new PagePrompt( PageType.Suggestion );

					break;
				}
			}
		}
	}
}