using System;
using Server;
using Server.Gumps;
using Server.Network;

namespace Server.Scripts.Gumps
{
	public class SkillsGump : Gump
	{
		private const int FieldsPerPage = 14;

		private Mobile m_From;
		private Mobile m_Mobile;

		public SkillsGump ( Mobile from, Mobile mobile ) : base ( 20, 30 )
		{
			m_From = from;
			m_Mobile = mobile;

			AddPage ( 0 );
			AddBackground( 0, 0, 260, 351, 5054 );

			AddImageTiled( 10, 10, 240, 23, 0x52 );
			AddImageTiled( 11, 11, 238, 21, 0xBBC );

			AddLabel( 65, 11, 0, "Skills" );

			AddPage( 1 );

			int page = 1;

			int index = 0;

			Skills skills = mobile.Skills;

			for ( int i = 0; i < skills.Length; ++i )
			{
				if ( index >= FieldsPerPage )
				{
					AddButton( 231, 13, 0x15E1, 0x15E5, 0, GumpButtonType.Page, page + 1 );

					++page;
					index = 0;

					AddPage( page );

					AddButton( 213, 13, 0x15E3, 0x15E7, 0, GumpButtonType.Page, page - 1 );
				}

				Skill skill = skills[i];

				AddImageTiled( 10, 32 + (index * 22), 240, 23, 0x52 );
				AddImageTiled( 11, 33 + (index * 22), 238, 21, 0xBBC );

				AddLabelCropped( 13, 33 + (index * 22), 150, 21, 0, skill.Name );
				AddImageTiled( 180, 34 + (index * 22), 50, 19, 0x52 );
				AddImageTiled( 181, 35 + (index * 22), 48, 17, 0xBBC );
				AddLabelCropped( 182, 35 + (index * 22), 234, 21, 0, skill.Base.ToString( "F1" ) );

				if ( from.AccessLevel >= AccessLevel.GameMaster )
					AddButton( 231, 35 + (index * 22), 0x15E1, 0x15E5, i + 1, GumpButtonType.Reply, 0 );
				else
					AddImage( 231, 35 + (index * 22), 0x2622 );

				++index;
			}
		}

		public override void OnResponse( NetState state, RelayInfo info )
		{
			if ( info.ButtonID > 0 && m_From.AccessLevel >= AccessLevel.GameMaster )
				m_From.SendGump( new EditSkillGump( m_From, m_Mobile, info.ButtonID - 1 ) );
		}
	}

	public class EditSkillGump : Gump
	{
		private Mobile m_From;
		private Mobile m_Mobile;
		private Skill m_Skill;

		public EditSkillGump( Mobile from, Mobile mobile, int skillNo ) : base ( 20, 30 )
		{
			m_From = from;
			m_Mobile = mobile;
			m_Skill = mobile.Skills[skillNo];

			if ( m_Skill == null )
				return;

			AddPage ( 0 );

			AddBackground( 0, 0, 90, 60, 5054 );

			AddImageTiled( 10, 10, 72, 22, 0x52 );
			AddImageTiled( 11, 11, 70, 20, 0xBBC );
			AddTextEntry( 11, 11, 70, 20, 0, 0, m_Skill.Base.ToString( "F1" ) );
			AddButton( 15, 35, 0xFB7, 0xFB8, 1, GumpButtonType.Reply, 0 );
			AddButton( 50, 35, 0xFB1, 0xFB2, 0, GumpButtonType.Reply, 0 );
		}

		public override void OnResponse( NetState state, RelayInfo info )
		{
			if ( info.ButtonID > 0 && m_From.AccessLevel >= AccessLevel.GameMaster )
			{
				TextRelay text = info.GetTextEntry( 0 );

				if ( text != null )
				{
					try
					{
						m_Skill.Base = Convert.ToDouble( text.Text );
						Server.Scripts.Commands.CommandLogging.LogChangeProperty( m_From, m_Mobile, String.Format( "{0}.Base", m_Skill ), m_Skill.Base.ToString() );
					}
					catch
					{
						state.Mobile.SendMessage( "Bad format. ###.# expected" );
					}
				}
			}

			state.Mobile.SendGump( new SkillsGump( m_From, m_Mobile ) );
		}
	}
}