using System;
using Server;

namespace Server.Misc
{
	public class WeightOverloading
	{
		public static void Initialize()
		{
			EventSink.Movement += new MovementEventHandler( EventSink_Movement );
		}

		public static void EventSink_Movement( MovementEventArgs e )
		{
			Mobile from = e.Mobile;

			if ( !from.Player || !from.Alive || from.AccessLevel >= AccessLevel.GameMaster )
				return;

			int maxWeight = 44 + (int)(3.5 * from.Str);
			int overWeight = (Mobile.BodyWeight + from.TotalWeight) - maxWeight;

			if ( overWeight <= 0 )
				return;

			from.Stam -= GetStamLoss( from, overWeight, (e.Direction & Direction.Running) != 0 );

			if ( from.Stam == 0 )
			{
				from.SendLocalizedMessage( 500110 ); // You are too fatigued to move.
				e.Blocked = true;
			}
		}

		public static int GetStamLoss( Mobile from, int overWeight, bool running )
		{
			int loss = 5 + (overWeight / 25);

			if ( from.Mounted )
				loss /= 3;

			if ( running )
				loss *= 2;

			return loss;
		}

		public static bool IsOverloaded( Mobile m )
		{
			if ( !m.Player || !m.Alive || m.AccessLevel >= AccessLevel.GameMaster )
				return false;

			if ( (Mobile.BodyWeight + m.TotalWeight) <= (44 + (int)(3.5 * m.Str)) )
				return false;

			return true;
		}
	}
}