using System;
using System.Collections;
using Server.Items;

namespace Server.Mobiles
{
	[CorpseName( "a plant corpse" )]
	public class BogThing : BaseCreature
	{
		[Constructable]
		public BogThing() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.6, 1.2 )
		{
			Body = 780;
			Name = "a bog thing";

			SetStr( 808, 845 );
			SetDex( 47, 57 );
			SetInt( 37, 49 );
			SetSkill( SkillName.Wrestling, 71, 81 );
			SetSkill( SkillName.Tactics, 73, 80 );
			SetSkill( SkillName.MagicResist, 90, 94 );

			VirtualArmor = 28;
			SetFameLevel( 4 );
			SetKarmaLevel( 4 );

			PackItem( new Log( 10 ) );

			PackItem( new Gold( 100, 150 ) );
		}

		public BogThing( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}

		public void SpawnBogling( Mobile m )
		{
			Map map = this.Map;

			if ( map == null )
				return;

			Bogling spawned = new Bogling();

			spawned.Team = this.Team;
			spawned.Map = map;

			bool validLocation = false;

			for ( int j = 0; !validLocation && j < 10; ++j )
			{
				int x = X + Utility.Random( 3 ) - 1;
				int y = Y + Utility.Random( 3 ) - 1;
				int z = map.GetAverageZ( x, y );

				if ( validLocation = map.CanFit( x, y, this.Z, 16, false, false ) )
					spawned.Location = new Point3D( x, y, Z );
				else if ( validLocation = map.CanFit( x, y, z, 16, false, false ) )
					spawned.Location = new Point3D( x, y, z );
			}

			if ( !validLocation )
				spawned.Location = this.Location;

			spawned.Combatant = m;
		}

		public void EatBoglings()
		{
			Map map = this.Map;

			if ( map == null )
				return;

			ArrayList toEat = new ArrayList();

			IPooledEnumerable eable = map.GetMobilesInRange( this.Location, 2 );
  
			foreach ( Mobile m in eable )
			{
				if ( m is Bogling )
					toEat.Add( m );
			}

			eable.Free();

			if ( toEat.Count > 0 )
			{
				PlaySound( Utility.Random( 0x3B, 2 ) ); // Eat sound

				foreach ( Mobile m in toEat )
				{
					Hits += (m.Hits / 2);
					m.Delete();
				}
			}
		}

		public override void OnGotMeleeAttack( Mobile attacker )
		{
			if ( this.Hits > (this.HitsMax / 4) )
			{
				if ( 0.25 >= Utility.RandomDouble() )
					SpawnBogling( attacker );
			}
			else if ( 0.25 >= Utility.RandomDouble() )
			{
				EatBoglings();
			}
		}
	}
}