using System;
using Server;
using Server.Items;
using Server.GenerateRandomMagicItems;
using Server.Engines.CannedEvil;

namespace Server.Mobiles
{
	public class LordOaks : BaseChampion
	{
		private Mobile m_Queen;
		private bool m_SpawnedQueen;

		public override ChampionSkullType SkullType{ get{ return ChampionSkullType.Enlightenment; } }

		[Constructable]
		public LordOaks() : base( AIType.AI_Mage )
		{
			Body = 175;
			Name = "Lord Oaks";

			SetFameLevel( 5 );
			SetKarmaLevel( 5 );

			SetStr( 544, 544 );
			SetDex( 289, 289 );
			SetInt( 634, 634 );

			VirtualArmor = 100;

			SetSkill( SkillName.Wrestling, 100, 100 );
			SetSkill( SkillName.Tactics, 100, 100 );
			SetSkill( SkillName.Anatomy, 95.4, 95.4 );
			SetSkill( SkillName.Magery, 120.0, 120.0 );
			SetSkill( SkillName.EvalInt, 120.9, 120.9 );
			SetSkill( SkillName.Meditation, 124.8, 124.8 );

			PackItem( new Gold( 3500, 6000 ) );

			PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 3, 5 ) );
			PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 5, 5 ) );

			switch ( Utility.Random( 9 ) )
			{
				case 0: PackItem( new Amber() ); break;
				case 1: PackItem( new Amethyst() ); break;
				case 2: PackItem( new Citrine() ); break;
				case 3: PackItem( new Diamond() ); break;
				case 4: PackItem( new Emerald() ); break;
				case 5: PackItem( new Ruby() ); break;
				case 6: PackItem( new Sapphire() ); break;
				case 7: PackItem( new StarSapphire() ); break;
				case 8: PackItem( new Tourmaline() ); break;
			}

			switch ( Utility.Random( 9 ) )
			{
				case 0: PackItem( new Amber() ); break;
				case 1: PackItem( new Amethyst() ); break;
				case 2: PackItem( new Citrine() ); break;
				case 3: PackItem( new Diamond() ); break;
				case 4: PackItem( new Emerald() ); break;
				case 5: PackItem( new Ruby() ); break;
				case 6: PackItem( new Sapphire() ); break;
				case 7: PackItem( new StarSapphire() ); break;
				case 8: PackItem( new Tourmaline() ); break;
			}
		}

		[CommandProperty( AccessLevel.GameMaster )]
		public override int HitsMax{ get{ return 5000; } }

		public void SpawnPixies( Mobile target )
		{
			Map map = this.Map;

			if ( map == null )
				return;

			this.Say( 1042154 ); // You shall never defeat me as long as I have my queen!

			int newPixies = Utility.RandomMinMax( 3, 6 );

			for ( int i = 0; i < newPixies; ++i )
			{
				Pixie pixie = new Pixie();

				pixie.Team = this.Team;
				pixie.FightMode = FightMode.Closest;
				pixie.Map = map;

				bool validLocation = false;

				for ( int j = 0; !validLocation && j < 10; ++j )
				{
					int x = X + Utility.Random( 3 ) - 1;
					int y = Y + Utility.Random( 3 ) - 1;
					int z = map.GetAverageZ( x, y );

					if ( validLocation = map.CanFit( x, y, this.Z, 16, false, false ) )
						pixie.Location = new Point3D( x, y, Z );
					else if ( validLocation = map.CanFit( x, y, z, 16, false, false ) )
						pixie.Location = new Point3D( x, y, z );
				}

				if ( !validLocation )
					pixie.Location = this.Location;

				pixie.Combatant = target;
			}
		}

		public override int GetAngerSound()
		{
			return 0x2F8;
		}

		public override int GetIdleSound()
		{
			return 0x2F8;
		}

		public override int GetAttackSound()
		{
			return Utility.Random( 0x2F5, 2 );
		}

		public override int GetHurtSound()
		{
			return 0x2F9;
		}

		public override int GetDeathSound()
		{
			return 0x2F7;
		}

		public void CheckQueen()
		{
			if ( !m_SpawnedQueen )
			{
				this.Say( 1042153 ); // Come forth my queen!

				m_Queen = new Silvani();

				((BaseCreature)m_Queen).Team = this.Team;

				m_Queen.Map = this.Map;
				m_Queen.Location = this.Location;

				m_SpawnedQueen = true;
			}
			else if ( m_Queen != null && m_Queen.Deleted )
			{
				m_Queen = null;
			}
		}

		public override void AlterDamageScalarFrom( Mobile caster, ref double scalar )
		{
			CheckQueen();

			if ( m_Queen != null )
			{
				scalar *= 0.1;

				if ( 0.1 >= Utility.RandomDouble() )
					SpawnPixies( caster );
			}
		}

		public override void OnGaveMeleeAttack( Mobile defender )
		{
			defender.Damage( Utility.Random( 20, 10 ) );
			defender.Stam -= Utility.Random( 20, 10 );
			defender.Mana -= Utility.Random( 20, 10 );
		}

		public override void OnGotMeleeAttack( Mobile attacker )
		{
			CheckQueen();

			if ( m_Queen != null && 0.1 >= Utility.RandomDouble() )
				SpawnPixies( attacker );

			attacker.Damage( Utility.Random( 20, 10 ) );
			attacker.Stam -= Utility.Random( 20, 10 );
			attacker.Mana -= Utility.Random( 20, 10 );
		}

		public LordOaks( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version

			writer.Write( m_Queen );
			writer.Write( m_SpawnedQueen );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();

			switch ( version )
			{
				case 0:
				{
					m_Queen = reader.ReadMobile();
					m_SpawnedQueen = reader.ReadBool();

					break;
				}
			}
		}
	}
}