using System;
using Server;
using Server.Items;
using Server.GenerateRandomMagicItems;
using Server.Engines.CannedEvil;

namespace Server.Mobiles
{
	public class Neira : BaseChampion
	{
		public override ChampionSkullType SkullType{ get{ return ChampionSkullType.Death; } }

		[Constructable]
		public Neira() : base( AIType.AI_Mage )
		{
			Body = 401;
			Female = true;
			Name = "Neira";
			Title = "the necromancer";
			Kills = 50;
			Hue = 0x83EC;

			SetFameLevel( 5 );
			SetKarmaLevel( 5 );

			SetStr( 363, 376 );
			SetDex( 96,  101 );
			SetInt( 627, 666 );

			VirtualArmor = 30;

			SetSkill( SkillName.Wrestling, 98.8, 98.8 );
			SetSkill( SkillName.Tactics, 98.3, 98.3 );
			SetSkill( SkillName.MagicResist, 150, 150 );
			SetSkill( SkillName.Magery, 120, 120 );
			SetSkill( SkillName.EvalInt, 100, 100 );
			SetSkill( SkillName.Meditation, 100, 100 );

			PackItem( new Gold( 2500, 3000 ) );

			PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 3, 5 ) );
			PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 5, 5 ) );

			Item shroud = new Item( 0x204E );

			shroud.LootType = LootType.Newbied;
			shroud.Hue = 0x497;
			shroud.Name = "shroud of shadows";
			shroud.Movable = false;
			shroud.Layer = Layer.OuterTorso;

			EquipItem( shroud );

			Scimitar weapon = new Scimitar();

			weapon.Skill = SkillName.Wrestling;
			weapon.LootType = LootType.Newbied;
			weapon.Hue = 38;
			weapon.Movable = false;

			EquipItem( weapon );

			new SkeletalMount().Rider = this;
		}

		public override bool OnBeforeDeath()
		{
			IMount mount = this.Mount;

			if ( mount != null )
				mount.Rider = null;

			if ( mount is Mobile )
				((Mobile)mount).Delete();

			return base.OnBeforeDeath();
		}

		[CommandProperty( AccessLevel.GameMaster )]
		public override int HitsMax{ get{ return 8000; } }

		public override bool ShowFameTitle{ get{ return false; } }

		public override bool ClickTitle{ get{ return false; } }

		protected override bool OnMove( Direction d )
		{
			if ( 0.25 >= Utility.RandomDouble() ) // 10% chance to drop an unholy bone
				new UnholyBone().MoveToWorld( Location, Map );

			return base.OnMove( d );
		}

		public override void OnGaveMeleeAttack( Mobile defender )
		{
			if ( 0.1 >= Utility.RandomDouble() ) // 10% chance to drop an unholy bone
				new UnholyBone().MoveToWorld( Location, Map );
		}

		public override void OnGotMeleeAttack( Mobile attacker )
		{
			if ( 0.1 >= Utility.RandomDouble() ) // 10% chance to drop an unholy bone
				new UnholyBone().MoveToWorld( Location, Map );
		}

		public Neira( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}
	}
}